跳到主要内容

AVColorTransferCharacteristic

搜索

枚举 AVColorTransferCharacteristic 

源代码
#[repr(i32)]
pub enum AVColorTransferCharacteristic {
Show 22 variants AVCOL_TRC_RESERVED0 = 0, AVCOL_TRC_BT709 = 1, AVCOL_TRC_UNSPECIFIED = 2, AVCOL_TRC_RESERVED = 3, AVCOL_TRC_GAMMA22 = 4, AVCOL_TRC_GAMMA28 = 5, AVCOL_TRC_SMPTE170M = 6, AVCOL_TRC_SMPTE240M = 7, AVCOL_TRC_LINEAR = 8, AVCOL_TRC_LOG = 9, AVCOL_TRC_LOG_SQRT = 10, AVCOL_TRC_IEC61966_2_4 = 11, AVCOL_TRC_BT1361_ECG = 12, AVCOL_TRC_IEC61966_2_1 = 13, AVCOL_TRC_BT2020_10 = 14, AVCOL_TRC_BT2020_12 = 15, AVCOL_TRC_SMPTE2084 = 16, AVCOL_TRC_SMPTE428 = 17, AVCOL_TRC_ARIB_STD_B67 = 18, AVCOL_TRC_NB = 19, AVCOL_TRC_EXT_BASE = 256, AVCOL_TRC_EXT_NB = 257,
}
展开描述

Color Transfer Characteristic. These values match the ones defined by ISO/IEC 23091-2_2019 subclause 8.2.

Variants



AVCOL_TRC_RESERVED0 = 0



AVCOL_TRC_BT709 = 1

< also ITU-R BT1361



AVCOL_TRC_UNSPECIFIED = 2



AVCOL_TRC_RESERVED = 3



AVCOL_TRC_GAMMA22 = 4

< also ITU-R BT470M / ITU-R BT1700 625 PAL & SECAM



AVCOL_TRC_GAMMA28 = 5

< also ITU-R BT470BG



AVCOL_TRC_SMPTE170M = 6

< also ITU-R BT601-6 525 or 625 / ITU-R BT1358 525 or 625 / ITU-R BT1700 NTSC



AVCOL_TRC_SMPTE240M = 7



AVCOL_TRC_LINEAR = 8

< “Linear transfer characteristics”



AVCOL_TRC_LOG = 9

< “Logarithmic transfer characteristic (100:1 range)”



AVCOL_TRC_LOG_SQRT = 10

< “Logarithmic transfer characteristic (100 * Sqrt(10) : 1 range)”



AVCOL_TRC_IEC61966_2_4 = 11

< IEC 61966-2-4



AVCOL_TRC_BT1361_ECG = 12

< ITU-R BT1361 Extended Colour Gamut



AVCOL_TRC_IEC61966_2_1 = 13

< IEC 61966-2-1 (sRGB or sYCC)



AVCOL_TRC_BT2020_10 = 14

< ITU-R BT2020 for 10-bit system



AVCOL_TRC_BT2020_12 = 15

< ITU-R BT2020 for 12-bit system



AVCOL_TRC_SMPTE2084 = 16

< SMPTE ST 2084 for 10-, 12-, 14- and 16-bit systems



AVCOL_TRC_SMPTE428 = 17

< SMPTE ST 428-1



AVCOL_TRC_ARIB_STD_B67 = 18

< ARIB STD-B67, known as “Hybrid log-gamma”



AVCOL_TRC_NB = 19

< Not part of ABI



AVCOL_TRC_EXT_BASE = 256



AVCOL_TRC_EXT_NB = 257

< Not part of ABI

实现

源代码

impl AVColorTransferCharacteristic

源代码

pub const AVCOL_TRC_SMPTEST2084: AVColorTransferCharacteristic = AVColorTransferCharacteristic::AVCOL_TRC_SMPTE2084

源代码

impl AVColorTransferCharacteristic

源代码

pub const AVCOL_TRC_SMPTEST428_1: AVColorTransferCharacteristic = AVColorTransferCharacteristic::AVCOL_TRC_SMPTE428

源代码

impl AVColorTransferCharacteristic

源代码

pub const AVCOL_TRC_V_LOG: AVColorTransferCharacteristic = AVColorTransferCharacteristic::AVCOL_TRC_EXT_BASE

trait 实现

源代码

impl Clone for AVColorTransferCharacteristic

源代码

fn clone(&self) -> AVColorTransferCharacteristic

Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码

fn clone_from(&mut self, source: &Self)

source 执行拷贝赋值。 阅读更多
源代码

impl Debug for AVColorTransferCharacteristic

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化该值。 阅读更多
源代码

impl Hash for AVColorTransferCharacteristic

源代码

fn hash<__H: Hasher>(&self, state: &mut __H)

Feeds this value into the given Hasher. 阅读更多
1.3.0 · 源代码

fn hash_slice<H>(data: &[Self], state: &mut H)
where H: Hasher, Self: Sized,

Feeds a slice of this type into the given Hasher. 阅读更多
源代码

impl PartialEq for AVColorTransferCharacteristic

源代码

fn eq(&self, other: &AVColorTransferCharacteristic) -> bool

Tests for self and other values to be equal, and is used by ==.
1.0.0 · 源代码

fn ne(&self, other: &Rhs) -> bool

测试 !=。默认实现几乎总是足够的,没有充分理由不应被重写。
源代码

impl Copy for AVColorTransferCharacteristic

源代码

impl Eq for AVColorTransferCharacteristic

源代码

impl StructuralPartialEq for AVColorTransferCharacteristic

自动 trait 实现

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

获取 selfTypeId阅读更多
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

从拥有的值不可变地借用。 阅读更多
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

从拥有的值可变地借用。 阅读更多
源代码

impl<T> CloneToUninit for T
where T: Clone,

源代码

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
self 执行拷贝赋值到 dest阅读更多
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of From<T> for U 实现选择执行的操作。

源代码

impl<T> ToOwned for T
where T: Clone,

源代码

type Owned = T

获取所有权后得到的类型。
源代码

fn to_owned(&self) -> T

通常通过克隆,从借用数据创建拥有的数据。 阅读更多
源代码

fn clone_into(&self, target: &mut T)

通常通过克隆,使用借用数据替换拥有的数据。 阅读更多
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行该转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行该转换。