#[repr(i32)]pub enum AVSampleFormat {
Show 14 variants
AV_SAMPLE_FMT_NONE = -1,
AV_SAMPLE_FMT_U8 = 0,
AV_SAMPLE_FMT_S16 = 1,
AV_SAMPLE_FMT_S32 = 2,
AV_SAMPLE_FMT_FLT = 3,
AV_SAMPLE_FMT_DBL = 4,
AV_SAMPLE_FMT_U8P = 5,
AV_SAMPLE_FMT_S16P = 6,
AV_SAMPLE_FMT_S32P = 7,
AV_SAMPLE_FMT_FLTP = 8,
AV_SAMPLE_FMT_DBLP = 9,
AV_SAMPLE_FMT_S64 = 10,
AV_SAMPLE_FMT_S64P = 11,
AV_SAMPLE_FMT_NB = 12,
}展开描述
Audio sample formats
-
The data described by the sample format is always in native-endian order. Sample values can be expressed by native C types, hence the lack of a signed 24-bit sample format even though it is a common raw audio data format.
-
The floating-point formats are based on full volume being in the range [-1.0, 1.0]. Any values outside this range are beyond full volume level.
-
The data layout as used in av_samples_fill_arrays() and elsewhere in FFmpeg (such as AVFrame in libavcodec) is as follows:
@par For planar sample formats, each audio channel is in a separate data plane, and linesize is the buffer size, in bytes, for a single plane. All data planes must be the same size. For packed sample formats, only the first data plane is used, and samples for each channel are interleaved. In this case, linesize is the buffer size, in bytes, for the 1 plane.
Variants
AV_SAMPLE_FMT_NONE = -1
AV_SAMPLE_FMT_U8 = 0
< unsigned 8 bits
AV_SAMPLE_FMT_S16 = 1
< signed 16 bits
AV_SAMPLE_FMT_S32 = 2
< signed 32 bits
AV_SAMPLE_FMT_FLT = 3
< float
AV_SAMPLE_FMT_DBL = 4
< double
AV_SAMPLE_FMT_U8P = 5
< unsigned 8 bits, planar
AV_SAMPLE_FMT_S16P = 6
< signed 16 bits, planar
AV_SAMPLE_FMT_S32P = 7
< signed 32 bits, planar
AV_SAMPLE_FMT_FLTP = 8
< float, planar
AV_SAMPLE_FMT_DBLP = 9
< double, planar
AV_SAMPLE_FMT_S64 = 10
< signed 64 bits
AV_SAMPLE_FMT_S64P = 11
< signed 64 bits, planar
AV_SAMPLE_FMT_NB = 12
< Number of sample formats. DO NOT USE if linking dynamically
trait 实现
源代码impl Clone for AVSampleFormat
impl Clone for AVSampleFormat
源代码fn clone(&self) -> AVSampleFormat
fn clone(&self) -> AVSampleFormat
1.0.0 · 源代码fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source 执行拷贝赋值。 阅读更多