#[repr(i32)]pub enum SwsFlags {
Show 20 variants
SWS_FAST_BILINEAR = 1,
SWS_BILINEAR = 2,
SWS_BICUBIC = 4,
SWS_X = 8,
SWS_POINT = 16,
SWS_AREA = 32,
SWS_BICUBLIN = 64,
SWS_GAUSS = 128,
SWS_SINC = 256,
SWS_LANCZOS = 512,
SWS_SPLINE = 1_024,
SWS_STRICT = 2_048,
SWS_PRINT_INFO = 4_096,
SWS_FULL_CHR_H_INT = 8_192,
SWS_FULL_CHR_H_INP = 16_384,
SWS_ACCURATE_RND = 262_144,
SWS_BITEXACT = 524_288,
SWS_UNSTABLE = 1_048_576,
SWS_DIRECT_BGR = 32_768,
SWS_ERROR_DIFFUSION = 8_388_608,
}Variants
SWS_FAST_BILINEAR = 1
< fast bilinear filtering
SWS_BILINEAR = 2
< bilinear filtering
SWS_BICUBIC = 4
< 2-tap cubic B-spline
SWS_X = 8
< experimental
SWS_POINT = 16
< nearest neighbor
SWS_AREA = 32
< area averaging
SWS_BICUBLIN = 64
< bicubic luma, bilinear chroma
SWS_GAUSS = 128
< gaussian approximation
SWS_SINC = 256
< unwindowed sinc
SWS_LANCZOS = 512
< 3-tap sinc/sinc
SWS_SPLINE = 1_024
< cubic Keys spline
SWS_STRICT = 2_048
Return an error on underspecified conversions. Without this flag, unspecified fields are defaulted to sensible values.
SWS_PRINT_INFO = 4_096
Emit verbose log of scaling parameters.
SWS_FULL_CHR_H_INT = 8_192
Perform full chroma upsampling when upscaling to RGB.
For example, when converting 50x50 yuv420p to 100x100 rgba, setting this flag will scale the chroma plane from 25x25 to 100x100 (4:4:4), and then convert the 100x100 yuv444p image to rgba in the final output step.
Without this flag, the chroma plane is instead scaled to 50x100 (4:2:2), with a single chroma sample being reused for both of the horizontally adjacent RGBA output pixels.
SWS_FULL_CHR_H_INP = 16_384
Perform full chroma interpolation when downscaling RGB sources.
For example, when converting a 100x100 rgba source to 50x50 yuv444p, setting this flag will generate a 100x100 (4:4:4) chroma plane, which is then downscaled to the required 50x50.
Without this flag, the chroma plane is instead generated at 50x100 (dropping every other pixel), before then being downscaled to the required 50x50 resolution.
SWS_ACCURATE_RND = 262_144
Force bit-exact output. This will prevent the use of platform-specific optimizations that may lead to slight difference in rounding, in favor of always maintaining exact bit output compatibility with the reference C code.
Note: It is recommended to set both of these flags simultaneously.
SWS_BITEXACT = 524_288
Force bit-exact output. This will prevent the use of platform-specific optimizations that may lead to slight difference in rounding, in favor of always maintaining exact bit output compatibility with the reference C code.
Note: It is recommended to set both of these flags simultaneously.
SWS_UNSTABLE = 1_048_576
Allow using experimental new code paths. This may be faster, slower, or produce different output, with semantics subject to change at any point in time. For testing and debugging purposes only.
SWS_DIRECT_BGR = 32_768
< This flag has no effect
SWS_ERROR_DIFFUSION = 8_388_608
< Set SwsContext.dither instead