#[repr(i32)]pub enum _bindgen_ty_2 {
AV_HWFRAME_MAP_READ = 1,
AV_HWFRAME_MAP_WRITE = 2,
AV_HWFRAME_MAP_OVERWRITE = 4,
AV_HWFRAME_MAP_DIRECT = 8,
}展开描述
Flags to apply to frame mappings.
Variants
AV_HWFRAME_MAP_READ = 1
The mapping must be readable.
AV_HWFRAME_MAP_WRITE = 2
The mapping must be writeable.
AV_HWFRAME_MAP_OVERWRITE = 4
The mapped frame will be overwritten completely in subsequent operations, so the current frame data need not be loaded. Any values which are not overwritten are unspecified.
AV_HWFRAME_MAP_DIRECT = 8
The mapping must be direct. That is, there must not be any copying in the map or unmap steps. Note that performance of direct mappings may be much lower than normal memory.
trait 实现
源代码impl Clone for _bindgen_ty_2
impl Clone for _bindgen_ty_2
源代码fn clone(&self) -> _bindgen_ty_2
fn clone(&self) -> _bindgen_ty_2
Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
从
source 执行拷贝赋值。 阅读更多源代码impl Debug for _bindgen_ty_2
impl Debug for _bindgen_ty_2
源代码impl Hash for _bindgen_ty_2
impl Hash for _bindgen_ty_2
源代码impl PartialEq for _bindgen_ty_2
impl PartialEq for _bindgen_ty_2
impl Copy for _bindgen_ty_2
impl Eq for _bindgen_ty_2
impl StructuralPartialEq for _bindgen_ty_2
自动 trait 实现
impl Freeze for _bindgen_ty_2
impl RefUnwindSafe for _bindgen_ty_2
impl Send for _bindgen_ty_2
impl Sync for _bindgen_ty_2
impl Unpin for _bindgen_ty_2
impl UnsafeUnpin for _bindgen_ty_2
impl UnwindSafe for _bindgen_ty_2
blanket 实现
源代码impl<T> BorrowMut<T> for Twhere
T: ?Sized,
impl<T> BorrowMut<T> for Twhere
T: ?Sized,
源代码fn borrow_mut(&mut self) -> &mut T
fn borrow_mut(&mut self) -> &mut T
从拥有的值可变地借用。 阅读更多