跳到主要内容

av_add_stable

搜索

函数 av_add_stable 

源代码
pub unsafe extern "C" fn av_add_stable(
    ts_tb: AVRational,
    ts: i64,
    inc_tb: AVRational,
    inc: i64,
) -> i64
展开描述

Add a value to a timestamp.

This function guarantees that when the same value is repeatedly added that no accumulation of rounding errors occurs.

@param[in] ts Input timestamp @param[in] ts_tb Input timestamp time base @param[in] inc Value to be added @param[in] inc_tb Time base of inc