跳到主要内容

av_audio_fifo_peek

搜索

函数 av_audio_fifo_peek 

源代码
pub unsafe extern "C" fn av_audio_fifo_peek(
    af: *const AVAudioFifo,
    data: *const *mut c_void,
    nb_samples: c_int,
) -> c_int
展开描述

Peek data from an AVAudioFifo.

@see enum AVSampleFormat The documentation for AVSampleFormat describes the data layout.

@param af AVAudioFifo to read from @param data audio data plane pointers @param nb_samples number of samples to peek @return number of samples actually peek, or negative AVERROR code on failure. The number of samples actually peek will not be greater than nb_samples, and will only be less than nb_samples if av_audio_fifo_size is less than nb_samples.