跳到主要内容

av_basename

搜索

函数 av_basename 

源代码
pub unsafe extern "C" fn av_basename(
    path: *const c_char,
) -> *const c_char
展开描述

Thread safe basename. @param path the string to parse, on DOS both \ and / are considered separators. @return pointer to the basename substring. If path does not contain a slash, the function returns a copy of path. If path is a NULL pointer or points to an empty string, a pointer to a string “.” is returned.