跳到主要内容

av_buffer_pool_get

搜索

函数 av_buffer_pool_get 

源代码
pub unsafe extern "C" fn av_buffer_pool_get(
    pool: *mut AVBufferPool,
) -> *mut AVBufferRef
展开描述

Allocate a new AVBuffer, reusing an old buffer from the pool when available. This function may be called simultaneously from multiple threads.

@return a reference to the new buffer on success, NULL on error.