跳到主要内容

av_buffersink_set_frame_size

搜索

函数 av_buffersink_set_frame_size 

源代码
pub unsafe extern "C" fn av_buffersink_set_frame_size(
    ctx: *mut AVFilterContext,
    frame_size: c_uint,
)
展开描述

Set the frame size for an audio buffer sink.

All calls to av_buffersink_get_buffer_ref will return a buffer with exactly the specified number of samples, or AVERROR(EAGAIN) if there is not enough. The last buffer at EOF will be padded with 0.