跳到主要内容

av_channel_layout_channel_from_string

搜索

函数 av_channel_layout_channel_from_string 

源代码
pub unsafe extern "C" fn av_channel_layout_channel_from_string(
    channel_layout: *const AVChannelLayout,
    name: *const c_char,
) -> AVChannel
展开描述

Get a channel described by the given string.

This function accepts channel names in the same format as @ref av_channel_from_string().

@param channel_layout input channel layout @param name string describing the channel to obtain @return a channel described by the given string in channel_layout on success or AV_CHAN_NONE on failure (if the string is not valid or the channel order is unspecified)