pub unsafe extern "C" fn av_channel_layout_compare(
chl: *const AVChannelLayout,
chl1: *const AVChannelLayout,
) -> c_int展开描述
Check whether two channel layouts are semantically the same, i.e. the same channels are present on the same positions in both.
If one of the channel layouts is AV_CHANNEL_ORDER_UNSPEC, while the other is not, they are considered to be unequal. If both are AV_CHANNEL_ORDER_UNSPEC, they are considered equal iff the channel counts are the same in both.
@param chl input channel layout @param chl1 input channel layout @return 0 if chl and chl1 are equal, 1 if they are not equal. A negative AVERROR code if one or both are invalid.