跳到主要内容

av_channel_layout_subset

搜索

函数 av_channel_layout_subset 

源代码
pub unsafe extern "C" fn av_channel_layout_subset(
    channel_layout: *const AVChannelLayout,
    mask: u64,
) -> u64
展开描述

Find out what channels from a given set are present in a channel layout, without regard for their positions.

@param channel_layout input channel layout @param mask a combination of AV_CH_* representing a set of channels @return a bitfield representing all the channels from mask that are present in channel_layout