跳到主要内容

av_codec_get_tag2

搜索

函数 av_codec_get_tag2 

源代码
pub unsafe extern "C" fn av_codec_get_tag2(
    tags: *const *const AVCodecTag,
    id: AVCodecID,
    tag: *mut c_uint,
) -> c_int
展开描述

Get the codec tag for the given codec id.

@param tags list of supported codec_id - codec_tag pairs, as stored in AVInputFormat.codec_tag and AVOutputFormat.codec_tag @param id codec id that should be searched for in the list @param tag A pointer to the found tag @return 0 if id was not found in tags, > 0 if it was found