跳到主要内容

av_d2q

搜索

函数 av_d2q 

源代码
pub unsafe extern "C" fn av_d2q(d: f64, max: c_int) -> AVRational
展开描述

Convert a double precision floating point number to a rational.

In case of infinity, the returned value is expressed as {1, 0} or {-1, 0} depending on the sign.

In general rational numbers with |num| <= 1<<26 && |den| <= 1<<26 can be recovered exactly from their double representation. (no exceptions were found within 1B random ones)

@param d double to convert @param max Maximum allowed numerator and denominator @return d in AVRational form @see av_q2d()