跳到主要内容

av_dict_set_int

搜索

函数 av_dict_set_int 

源代码
pub unsafe extern "C" fn av_dict_set_int(
    pm: *mut *mut AVDictionary,
    key: *const c_char,
    value: i64,
    flags: c_int,
) -> c_int
展开描述

Convenience wrapper for av_dict_set() that converts the value to a string and stores it.

Note: If ::AV_DICT_DONT_STRDUP_KEY is set, key will be freed on error.