pub unsafe extern "C" fn av_disposition_to_string(
disposition: c_int,
) -> *const c_char展开描述
@param disposition a combination of AV_DISPOSITION_* values @return The string description corresponding to the lowest set bit in disposition. NULL when the lowest set bit does not correspond to a known disposition or when disposition is 0.