跳到主要内容

av_downmix_info_update_side_data

搜索

函数 av_downmix_info_update_side_data 

源代码
pub unsafe extern "C" fn av_downmix_info_update_side_data(
    frame: *mut AVFrame,
) -> *mut AVDownmixInfo
展开描述

Get a frame’s AV_FRAME_DATA_DOWNMIX_INFO side data for editing.

If the side data is absent, it is created and added to the frame.

@param frame the frame for which the side data is to be obtained or created

@return the AVDownmixInfo structure to be edited by the caller, or NULL if the structure cannot be allocated.