跳到主要内容

av_find_nearest_q_idx

搜索

函数 av_find_nearest_q_idx 

源代码
pub unsafe extern "C" fn av_find_nearest_q_idx(
    q: AVRational,
    q_list: *const AVRational,
) -> c_int
展开描述

Find the value in a list of rationals nearest a given reference rational.

@param q Reference rational @param q_list Array of rationals terminated by {0, 0} @return Index of the nearest value found in the array