跳到主要内容

av_frame_free

搜索

函数 av_frame_free 

源代码
pub unsafe extern "C" fn av_frame_free(frame: *mut *mut AVFrame)
展开描述

Free the frame and any dynamically allocated objects in it, e.g. extended_data. If the frame is reference counted, it will be unreferenced first.

@param frame frame to be freed. The pointer will be set to NULL.