跳到主要内容

av_frame_get_plane_buffer

搜索

函数 av_frame_get_plane_buffer 

源代码
pub unsafe extern "C" fn av_frame_get_plane_buffer(
    frame: *const AVFrame,
    plane: c_int,
) -> *mut AVBufferRef
展开描述

Get the buffer reference a given data plane is stored in.

@param frame the frame to get the plane’s buffer from @param plane index of the data plane of interest in frame->extended_data.

@return the buffer reference that contains the plane or NULL if the input frame is not valid.