pub unsafe extern "C" fn av_frame_remove_side_data(
frame: *mut AVFrame,
type_: AVFrameSideDataType,
)展开描述
Remove and free all side data instances of the given type.
pub unsafe extern "C" fn av_frame_remove_side_data(
frame: *mut AVFrame,
type_: AVFrameSideDataType,
)Remove and free all side data instances of the given type.