跳到主要内容

av_frame_side_data_free

搜索

函数 av_frame_side_data_free 

源代码
pub unsafe extern "C" fn av_frame_side_data_free(
    sd: *mut *mut *mut AVFrameSideData,
    nb_sd: *mut c_int,
)
展开描述

Free all side data entries and their contents, then zeroes out the values which the pointers are pointing to.

@param sd pointer to array of side data to free. Will be set to NULL upon return. @param nb_sd pointer to an integer containing the number of entries in the array. Will be set to 0 upon return.