跳到主要内容

av_get_output_timestamp

搜索

函数 av_get_output_timestamp 

源代码
pub unsafe extern "C" fn av_get_output_timestamp(
    s: *mut AVFormatContext,
    stream: c_int,
    dts: *mut i64,
    wall: *mut i64,
) -> c_int
展开描述

Get timing information for the data currently output. The exact meaning of “currently output” depends on the format. It is mostly relevant for devices that have an internal buffer and/or work in real time. @param s media file handle @param stream stream in the media file @param[out] dts DTS of the last packet output for the stream, in stream time_base units @param[out] wall absolute time when that packet whas output, in microsecond @retval 0 Success @retval AVERROR(ENOSYS) The format does not support it

@note Some formats or devices may not allow to measure dts and wall atomically.