跳到主要内容

av_get_picture_type_char

搜索

函数 av_get_picture_type_char 

源代码
pub unsafe extern "C" fn av_get_picture_type_char(
    pict_type: AVPictureType,
) -> c_char
展开描述

Return a single letter to describe the given picture type pict_type.

@param[in] pict_type the picture type @return a single character representing the picture type, ‘?’ if pict_type is unknown