跳到主要内容

av_get_random_seed

搜索

函数 av_get_random_seed 

源代码
pub unsafe extern "C" fn av_get_random_seed() -> u32
展开描述

Get a seed to use in conjunction with random functions. This function tries to provide a good seed at a best effort bases. Its possible to call this function multiple times if more bits are needed. It can be quite slow, which is why it should only be used as seed for a faster PRNG. The quality of the seed depends on the platform.