pub unsafe extern "C" fn av_get_time_base_q() -> AVRational展开描述
Return the fractional representation of the internal time base.
pub unsafe extern "C" fn av_get_time_base_q() -> AVRationalReturn the fractional representation of the internal time base.