跳到主要内容

av_hash_names

搜索

函数 av_hash_names 

源代码
pub unsafe extern "C" fn av_hash_names(i: c_int) -> *const c_char
展开描述

Get the names of available hash algorithms.

This function can be used to enumerate the algorithms.

@param[in] i Index of the hash algorithm, starting from 0 @return Pointer to a static string or NULL if i is out of range