跳到主要内容

av_hwframe_ctx_alloc

搜索

函数 av_hwframe_ctx_alloc 

源代码
pub unsafe extern "C" fn av_hwframe_ctx_alloc(
    device_ctx: *mut AVBufferRef,
) -> *mut AVBufferRef
展开描述

Allocate an AVHWFramesContext tied to a given device context.

@param device_ctx a reference to a AVHWDeviceContext. This function will make a new reference for internal use, the one passed to the function remains owned by the caller. @return a reference to the newly created AVHWFramesContext on success or NULL on failure.