跳到主要内容

av_hwframe_ctx_init

搜索

函数 av_hwframe_ctx_init 

源代码
pub unsafe extern "C" fn av_hwframe_ctx_init(
    ref_: *mut AVBufferRef,
) -> c_int
展开描述

Finalize the context before use. This function must be called after the context is filled with all the required information and before it is attached to any frames.

@param ref a reference to the AVHWFramesContext @return 0 on success, a negative AVERROR code on failure