跳到主要内容

av_hwframe_get_buffer

搜索

函数 av_hwframe_get_buffer 

源代码
pub unsafe extern "C" fn av_hwframe_get_buffer(
    hwframe_ctx: *mut AVBufferRef,
    frame: *mut AVFrame,
    flags: c_int,
) -> c_int
展开描述

Allocate a new frame attached to the given AVHWFramesContext.

@param hwframe_ctx a reference to an AVHWFramesContext @param frame an empty (freshly allocated or unreffed) frame to be filled with newly allocated buffers. @param flags currently unused, should be set to zero @return 0 on success, a negative AVERROR code on failure