跳到主要内容

av_int_list_length_for_size

搜索

函数 av_int_list_length_for_size 

源代码
pub unsafe extern "C" fn av_int_list_length_for_size(
    elsize: c_uint,
    list: *const c_void,
    term: u64,
) -> c_uint
展开描述

Compute the length of an integer list.

@param elsize size in bytes of each list element (only 1, 2, 4 or 8) @param term list terminator (usually 0 or -1) @param list pointer to the list @return length of the list, in elements, not counting the terminator