跳到主要内容

av_opt_ptr

搜索

函数 av_opt_ptr 

源代码
pub unsafe extern "C" fn av_opt_ptr(
    avclass: *const AVClass,
    obj: *mut c_void,
    name: *const c_char,
) -> *mut c_void
展开描述

Gets a pointer to the requested field in a struct. This function allows accessing a struct even when its fields are moved or renamed since the application making the access has been compiled,

@returns a pointer to the field, it can be cast to the correct type and read or written to.

@deprecated direct access to AVOption-exported fields is not supported