pub unsafe extern "C" fn av_opt_set_chlayout(
obj: *mut c_void,
name: *const c_char,
layout: *const AVChannelLayout,
search_flags: c_int,
) -> c_int展开描述
@note Any old chlayout present is discarded and replaced with a copy of the new one. The caller still owns layout and is responsible for uninitializing it.