跳到主要内容

av_packet_side_data_remove

搜索

函数 av_packet_side_data_remove 

源代码
pub unsafe extern "C" fn av_packet_side_data_remove(
    sd: *mut AVPacketSideData,
    nb_sd: *mut c_int,
    type_: AVPacketSideDataType,
)
展开描述

Remove side data of the given type from a side data array.

@param sd the array from which the side data should be removed @param nb_sd pointer to an integer containing the number of entries in the array. Will be reduced by the amount of entries removed upon return @param type side information type