跳到主要内容

av_packet_unref

搜索

函数 av_packet_unref 

源代码
pub unsafe extern "C" fn av_packet_unref(pkt: *mut AVPacket)
展开描述

Wipe the packet.

Unreference the buffer referenced by the packet and reset the remaining packet fields to their default values.

@param pkt The packet to be unreferenced.