跳到主要内容

av_timecode_make_string

搜索

函数 av_timecode_make_string 

源代码
pub unsafe extern "C" fn av_timecode_make_string(
    tc: *const AVTimecode,
    buf: *mut c_char,
    framenum: c_int,
) -> *mut c_char
展开描述

Load timecode string in buf.

@param tc timecode data correctly initialized @param buf destination buffer, must be at least AV_TIMECODE_STR_SIZE long @param framenum frame number @return the buf parameter

@note Timecode representation can be a negative timecode and have more than 24 hours, but will only be honored if the flags are correctly set. @note The frame number is relative to tc->start.