跳到主要内容

avcodec_parameters_from_context

搜索

函数 avcodec_parameters_from_context 

源代码
pub unsafe extern "C" fn avcodec_parameters_from_context(
    par: *mut AVCodecParameters,
    codec: *const AVCodecContext,
) -> c_int
展开描述

Fill the parameters struct based on the values from the supplied codec context. Any allocated fields in par are freed and replaced with duplicates of the corresponding fields in codec.

@return >= 0 on success, a negative AVERROR code on failure