pub unsafe extern "C" fn avfilter_graph_create_filter(
filt_ctx: *mut *mut AVFilterContext,
filt: *const AVFilter,
name: *const c_char,
args: *const c_char,
opaque: *mut c_void,
graph_ctx: *mut AVFilterGraph,
) -> c_int展开描述
A convenience wrapper that allocates and initializes a filter in a single step. The filter instance is created from the filter filt and inited with the parameter args. opaque is currently ignored.
In case of success put in *filt_ctx the pointer to the created filter instance, otherwise set *filt_ctx to NULL.
@param name the instance name to give to the created filter instance @param graph_ctx the filter graph @return a negative AVERROR error code in case of failure, a non negative value otherwise
@warning Since the filter is initialized after this function successfully returns, you MUST NOT set any further options on it. If you need to do that, call ::avfilter_graph_alloc_filter(), followed by setting the options, followed by ::avfilter_init_dict() instead of this function.