跳到主要内容

avfilter_graph_get_filter

搜索

函数 avfilter_graph_get_filter 

源代码
pub unsafe extern "C" fn avfilter_graph_get_filter(
    graph: *mut AVFilterGraph,
    name: *const c_char,
) -> *mut AVFilterContext
展开描述

Get a filter instance identified by instance name from graph.

@param graph filter graph to search through. @param name filter instance name (should be unique in the graph). @return the pointer to the found filter instance or NULL if it cannot be found.