跳到主要内容

avfilter_graph_set_auto_convert

搜索

函数 avfilter_graph_set_auto_convert 

源代码
pub unsafe extern "C" fn avfilter_graph_set_auto_convert(
    graph: *mut AVFilterGraph,
    flags: c_uint,
)
展开描述

Enable or disable automatic format conversion inside the graph.

Note that format conversion can still happen inside explicitly inserted scale and aresample filters.

@param flags any of the AVFILTER_AUTO_CONVERT_* constants