跳到主要内容

avformat_alloc_output_context2

搜索

函数 avformat_alloc_output_context2 

源代码
pub unsafe extern "C" fn avformat_alloc_output_context2(
    ctx: *mut *mut AVFormatContext,
    oformat: *const AVOutputFormat,
    format_name: *const c_char,
    filename: *const c_char,
) -> c_int
展开描述

Allocate an AVFormatContext for an output format. avformat_free_context() can be used to free the context and everything allocated by the framework within it.

@param ctx pointee is set to the created format context, or to NULL in case of failure @param oformat format to use for allocating the context, if NULL format_name and filename are used instead @param format_name the name of output format to use for allocating the context, if NULL filename is used instead @param filename the name of the filename to use for allocating the context, may be NULL

@return >= 0 in case of success, a negative AVERROR code in case of failure