跳到主要内容

avformat_index_get_entries_count

搜索

函数 avformat_index_get_entries_count 

源代码
pub unsafe extern "C" fn avformat_index_get_entries_count(
    st: *const AVStream,
) -> c_int
展开描述

Get the index entry count for the given AVStream.

@param st stream @return the number of index entries in the stream