跳到主要内容

avformat_network_init

搜索

函数 avformat_network_init 

源代码
pub unsafe extern "C" fn avformat_network_init() -> c_int
展开描述

Do global initialization of network libraries. This is optional, and not recommended anymore.

This functions only exists to work around thread-safety issues with older GnuTLS or OpenSSL libraries. If libavformat is linked to newer versions of those libraries, or if you do not use them, calling this function is unnecessary. Otherwise, you need to call this function before any other threads using them are started.

This function will be deprecated once support for older GnuTLS and OpenSSL libraries is removed, and this function has no purpose anymore.