跳到主要内容

avio_check

搜索

函数 avio_check 

源代码
pub unsafe extern "C" fn avio_check(
    url: *const c_char,
    flags: c_int,
) -> c_int
展开描述

Return AVIO_FLAG_* access flags corresponding to the access permissions of the resource in url, or a negative value corresponding to an AVERROR code in case of failure. The returned access flags are masked by the value in flags.

@note This function is intrinsically unsafe, in the sense that the checked resource may change its existence or permission status from one call to another. Thus you should not trust the returned value, unless you are sure that no other processes are accessing the checked resource.