跳到主要内容

avio_close

搜索

函数 avio_close 

源代码
pub unsafe extern "C" fn avio_close(s: *mut AVIOContext) -> c_int
展开描述

Close the resource accessed by the AVIOContext s and free it. This function can only be used if s was opened by avio_open().

The internal buffer is automatically flushed before closing the resource.

@return 0 on success, an AVERROR < 0 on error. @see avio_closep