跳到主要内容

avio_feof

搜索

函数 avio_feof 

源代码
pub unsafe extern "C" fn avio_feof(s: *mut AVIOContext) -> c_int
展开描述

Similar to feof() but also returns nonzero on read errors. @return non zero if and only if at end of file or a read error happened when reading.