跳到主要内容

sws_receive_slice_alignment

搜索

函数 sws_receive_slice_alignment 

源代码
pub unsafe extern "C" fn sws_receive_slice_alignment(
    c: *const SwsContext,
) -> c_uint
展开描述

Get the alignment required for slices. Requires a context that has previously been initialized with sws_init_context().

@param c The scaling context @return alignment required for output slices requested with sws_receive_slice(). Slice offsets and sizes passed to sws_receive_slice() must be multiples of the value returned from this function.