#[repr(C)]pub struct AVCPBProperties {
pub max_bitrate: i64,
pub min_bitrate: i64,
pub avg_bitrate: i64,
pub buffer_size: i64,
pub vbv_delay: u64,
}展开描述
This structure describes the bitrate properties of an encoded bitstream. It roughly corresponds to a subset the VBV parameters for MPEG-2 or HRD parameters for H.264/HEVC.
Fields
max_bitrate: i64Maximum bitrate of the stream, in bits per second. Zero if unknown or unspecified.
min_bitrate: i64Minimum bitrate of the stream, in bits per second. Zero if unknown or unspecified.
avg_bitrate: i64Average bitrate of the stream, in bits per second. Zero if unknown or unspecified.
buffer_size: i64The size of the buffer to which the ratecontrol is applied, in bits. Zero if unknown or unspecified.
vbv_delay: u64The delay between the time the packet this structure is associated with is received and the time when it should be decoded, in periods of a 27MHz clock.
UINT64_MAX when unknown or unspecified.
trait 实现
源代码impl Clone for AVCPBProperties
impl Clone for AVCPBProperties
源代码fn clone(&self) -> AVCPBProperties
fn clone(&self) -> AVCPBProperties
Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
从
source 执行拷贝赋值。 阅读更多源代码impl Debug for AVCPBProperties
impl Debug for AVCPBProperties
源代码impl PartialEq for AVCPBProperties
impl PartialEq for AVCPBProperties
impl Copy for AVCPBProperties
impl Eq for AVCPBProperties
impl StructuralPartialEq for AVCPBProperties
自动 trait 实现
impl Freeze for AVCPBProperties
impl RefUnwindSafe for AVCPBProperties
impl Send for AVCPBProperties
impl Sync for AVCPBProperties
impl Unpin for AVCPBProperties
impl UnsafeUnpin for AVCPBProperties
impl UnwindSafe for AVCPBProperties
blanket 实现
源代码impl<T> BorrowMut<T> for Twhere
T: ?Sized,
impl<T> BorrowMut<T> for Twhere
T: ?Sized,
源代码fn borrow_mut(&mut self) -> &mut T
fn borrow_mut(&mut self) -> &mut T
从拥有的值可变地借用。 阅读更多