#[repr(C)]pub struct AVDRMLayerDescriptor {
pub format: u32,
pub nb_planes: c_int,
pub planes: [AVDRMPlaneDescriptor; 4],
}展开描述
DRM layer descriptor.
Describes a single layer within a frame. This has the structure defined by its format, and will contain one or more planes.
Fields
format: u32Format of the layer (DRM_FORMAT_*).
nb_planes: c_intNumber of planes in the layer.
This must match the number of planes required by format.
planes: [AVDRMPlaneDescriptor; 4]Array of planes in this layer.
trait 实现
源代码impl Clone for AVDRMLayerDescriptor
impl Clone for AVDRMLayerDescriptor
源代码fn clone(&self) -> AVDRMLayerDescriptor
fn clone(&self) -> AVDRMLayerDescriptor
Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
从
source 执行拷贝赋值。 阅读更多源代码impl Debug for AVDRMLayerDescriptor
impl Debug for AVDRMLayerDescriptor
源代码impl PartialEq for AVDRMLayerDescriptor
impl PartialEq for AVDRMLayerDescriptor
impl Copy for AVDRMLayerDescriptor
impl Eq for AVDRMLayerDescriptor
impl StructuralPartialEq for AVDRMLayerDescriptor
自动 trait 实现
impl Freeze for AVDRMLayerDescriptor
impl RefUnwindSafe for AVDRMLayerDescriptor
impl Send for AVDRMLayerDescriptor
impl Sync for AVDRMLayerDescriptor
impl Unpin for AVDRMLayerDescriptor
impl UnsafeUnpin for AVDRMLayerDescriptor
impl UnwindSafe for AVDRMLayerDescriptor
blanket 实现
源代码impl<T> BorrowMut<T> for Twhere
T: ?Sized,
impl<T> BorrowMut<T> for Twhere
T: ?Sized,
源代码fn borrow_mut(&mut self) -> &mut T
fn borrow_mut(&mut self) -> &mut T
从拥有的值可变地借用。 阅读更多