#[repr(C)]pub struct AVFilterGraphSegment {
pub graph: *mut AVFilterGraph,
pub chains: *mut *mut AVFilterChain,
pub nb_chains: usize,
pub scale_sws_opts: *mut c_char,
}展开描述
A parsed representation of a filtergraph segment.
A filtergraph segment is conceptually a list of filterchains, with some supplementary information (e.g. format conversion flags).
Created by avfilter_graph_segment_parse(). Must be freed with avfilter_graph_segment_free().
Fields
graph: *mut AVFilterGraphThe filtergraph this segment is associated with. Set by avfilter_graph_segment_parse().
chains: *mut *mut AVFilterChainA list of filter chain contained in this segment. Set in avfilter_graph_segment_parse().
nb_chains: usizescale_sws_opts: *mut c_charA string containing a colon-separated list of key=value options applied to all scale filters in this segment.
May be set by avfilter_graph_segment_parse(). The caller may free this string with av_free() and replace it with a different av_malloc()’ed string.
trait 实现
源代码impl Clone for AVFilterGraphSegment
impl Clone for AVFilterGraphSegment
源代码fn clone(&self) -> AVFilterGraphSegment
fn clone(&self) -> AVFilterGraphSegment
Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
从
source 执行拷贝赋值。 阅读更多源代码impl Debug for AVFilterGraphSegment
impl Debug for AVFilterGraphSegment
源代码impl PartialEq for AVFilterGraphSegment
impl PartialEq for AVFilterGraphSegment
impl Copy for AVFilterGraphSegment
impl Eq for AVFilterGraphSegment
impl StructuralPartialEq for AVFilterGraphSegment
自动 trait 实现
impl Freeze for AVFilterGraphSegment
impl RefUnwindSafe for AVFilterGraphSegment
impl !Send for AVFilterGraphSegment
impl !Sync for AVFilterGraphSegment
impl Unpin for AVFilterGraphSegment
impl UnsafeUnpin for AVFilterGraphSegment
impl UnwindSafe for AVFilterGraphSegment
blanket 实现
源代码impl<T> BorrowMut<T> for Twhere
T: ?Sized,
impl<T> BorrowMut<T> for Twhere
T: ?Sized,
源代码fn borrow_mut(&mut self) -> &mut T
fn borrow_mut(&mut self) -> &mut T
从拥有的值可变地借用。 阅读更多