跳到主要内容

AVFilterParams

搜索

结构体 AVFilterParams 

源代码
#[repr(C)]
pub struct AVFilterParams { pub filter: *mut AVFilterContext, pub filter_name: *mut c_char, pub instance_name: *mut c_char, pub opts: *mut AVDictionary, pub inputs: *mut *mut AVFilterPadParams, pub nb_inputs: c_uint, pub outputs: *mut *mut AVFilterPadParams, pub nb_outputs: c_uint, }
展开描述

Parameters describing a filter to be created in a filtergraph.

Created as a child of AVFilterGraphSegment by avfilter_graph_segment_parse(). Freed in avfilter_graph_segment_free().

Fields

filter: *mut AVFilterContext

The filter context.

Created by avfilter_graph_segment_create_filters() based on AVFilterParams.filter_name and instance_name.

Callers may also create the filter context manually, then they should av_free() filter_name and set it to NULL. Such AVFilterParams instances are then skipped by avfilter_graph_segment_create_filters().

filter_name: *mut c_char

Name of the AVFilter to be used.

An av_malloc()’ed string, set by avfilter_graph_segment_parse(). Will be passed to avfilter_get_by_name() by avfilter_graph_segment_create_filters().

Callers may av_free() this string and replace it with another one or NULL. If the caller creates the filter instance manually, this string MUST be set to NULL.

When both AVFilterParams.filter an AVFilterParams.filter_name are NULL, this AVFilterParams instance is skipped by avfilter_graph_segment_*() functions.

instance_name: *mut c_char

Name to be used for this filter instance.

An av_malloc()’ed string, may be set by avfilter_graph_segment_parse() or left NULL. The caller may av_free() this string and replace with another one or NULL.

Will be used by avfilter_graph_segment_create_filters() - passed as the third argument to avfilter_graph_alloc_filter(), then freed and set to NULL.

opts: *mut AVDictionary

Options to be applied to the filter.

Filled by avfilter_graph_segment_parse(). Afterwards may be freely modified by the caller.

Will be applied to the filter by avfilter_graph_segment_apply_opts() with an equivalent of av_opt_set_dict2(filter, &opts, AV_OPT_SEARCH_CHILDREN), i.e. any unapplied options will be left in this dictionary.

inputs: *mut *mut AVFilterPadParamsnb_inputs: c_uintoutputs: *mut *mut AVFilterPadParamsnb_outputs: c_uint

trait 实现

源代码

impl Clone for AVFilterParams

源代码

fn clone(&self) -> AVFilterParams

Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码

fn clone_from(&mut self, source: &Self)

source 执行拷贝赋值。 阅读更多
源代码

impl Debug for AVFilterParams

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化该值。 阅读更多
源代码

impl PartialEq for AVFilterParams

源代码

fn eq(&self, other: &AVFilterParams) -> bool

Tests for self and other values to be equal, and is used by ==.
1.0.0 · 源代码

fn ne(&self, other: &Rhs) -> bool

测试 !=。默认实现几乎总是足够的,没有充分理由不应被重写。
源代码

impl Copy for AVFilterParams

源代码

impl Eq for AVFilterParams

源代码

impl StructuralPartialEq for AVFilterParams

自动 trait 实现

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

获取 selfTypeId阅读更多
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

从拥有的值不可变地借用。 阅读更多
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

从拥有的值可变地借用。 阅读更多
源代码

impl<T> CloneToUninit for T
where T: Clone,

源代码

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
self 执行拷贝赋值到 dest阅读更多
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of From<T> for U 实现选择执行的操作。

源代码

impl<T> ToOwned for T
where T: Clone,

源代码

type Owned = T

获取所有权后得到的类型。
源代码

fn to_owned(&self) -> T

通常通过克隆,从借用数据创建拥有的数据。 阅读更多
源代码

fn clone_into(&self, target: &mut T)

通常通过克隆,使用借用数据替换拥有的数据。 阅读更多
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行该转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行该转换。