pub struct AVHashContext { /* 私有字段 */ }展开描述
@example ffhash.c This example is a simple command line application that takes one or more arguments. It demonstrates a typical use of the hashing API with allocation, initialization, updating, and finalizing.
trait 实现
源代码impl Clone for AVHashContext
impl Clone for AVHashContext
源代码fn clone(&self) -> AVHashContext
fn clone(&self) -> AVHashContext
Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
从
source 执行拷贝赋值。 阅读更多源代码impl Debug for AVHashContext
impl Debug for AVHashContext
impl Copy for AVHashContext
自动 trait 实现
impl Freeze for AVHashContext
impl RefUnwindSafe for AVHashContext
impl Send for AVHashContext
impl Sync for AVHashContext
impl Unpin for AVHashContext
impl UnsafeUnpin for AVHashContext
impl UnwindSafe for AVHashContext
blanket 实现
源代码impl<T> BorrowMut<T> for Twhere
T: ?Sized,
impl<T> BorrowMut<T> for Twhere
T: ?Sized,
源代码fn borrow_mut(&mut self) -> &mut T
fn borrow_mut(&mut self) -> &mut T
从拥有的值可变地借用。 阅读更多