跳到主要内容

AVIODirEntry

搜索

结构体 AVIODirEntry 

源代码
#[repr(C)]
pub struct AVIODirEntry { pub name: *mut c_char, pub type_: c_int, pub utf8: c_int, pub size: i64, pub modification_timestamp: i64, pub access_timestamp: i64, pub status_change_timestamp: i64, pub user_id: i64, pub group_id: i64, pub filemode: i64, }
展开描述

Describes single entry of the directory.

Only name and type fields are guaranteed be set. Rest of fields are protocol or/and platform dependent and might be unknown.

Fields

name: *mut c_char

< Filename

type_: c_int

< Type of the entry

utf8: c_int

< Set to 1 when name is encoded with UTF-8, 0 otherwise. Name can be encoded with UTF-8 even though 0 is set.

size: i64

< File size in bytes, -1 if unknown.

modification_timestamp: i64

< Time of last modification in microseconds since unix epoch, -1 if unknown.

access_timestamp: i64

< Time of last access in microseconds since unix epoch, -1 if unknown.

status_change_timestamp: i64

< Time of last status change in microseconds since unix epoch, -1 if unknown.

user_id: i64

< User ID of owner, -1 if unknown.

group_id: i64

< Group ID of owner, -1 if unknown.

filemode: i64

< Unix file mode, -1 if unknown.

trait 实现

源代码

impl Clone for AVIODirEntry

源代码

fn clone(&self) -> AVIODirEntry

Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码

fn clone_from(&mut self, source: &Self)

source 执行拷贝赋值。 阅读更多
源代码

impl Debug for AVIODirEntry

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化该值。 阅读更多
源代码

impl PartialEq for AVIODirEntry

源代码

fn eq(&self, other: &AVIODirEntry) -> bool

Tests for self and other values to be equal, and is used by ==.
1.0.0 · 源代码

fn ne(&self, other: &Rhs) -> bool

测试 !=。默认实现几乎总是足够的,没有充分理由不应被重写。
源代码

impl Copy for AVIODirEntry

源代码

impl Eq for AVIODirEntry

源代码

impl StructuralPartialEq for AVIODirEntry

自动 trait 实现

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

获取 selfTypeId阅读更多
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

从拥有的值不可变地借用。 阅读更多
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

从拥有的值可变地借用。 阅读更多
源代码

impl<T> CloneToUninit for T
where T: Clone,

源代码

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
self 执行拷贝赋值到 dest阅读更多
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of From<T> for U 实现选择执行的操作。

源代码

impl<T> ToOwned for T
where T: Clone,

源代码

type Owned = T

获取所有权后得到的类型。
源代码

fn to_owned(&self) -> T

通常通过克隆,从借用数据创建拥有的数据。 阅读更多
源代码

fn clone_into(&self, target: &mut T)

通常通过克隆,使用借用数据替换拥有的数据。 阅读更多
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行该转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行该转换。