#[repr(C)]pub struct AVIndexEntry {
pub pos: i64,
pub timestamp: i64,
pub _bitfield_align_1: [u32; 0],
pub _bitfield_1: __BindgenBitfieldUnit<[u8; 4]>,
pub min_distance: c_int,
}Fields
pos: i64timestamp: i64< Timestamp in AVStream.time_base units, preferably the time from which on correctly decoded frames are available when seeking to this entry. That means preferable PTS on keyframe based formats. But demuxers can choose to store a different timestamp, if it is more convenient for the implementation or nothing better is known
_bitfield_align_1: [u32; 0]_bitfield_1: __BindgenBitfieldUnit<[u8; 4]>min_distance: c_int< Minimum distance between this and the previous keyframe, used to avoid unneeded searching.
实现
源代码impl AVIndexEntry
impl AVIndexEntry
pub fn flags(&self) -> c_int
pub fn set_flags(&mut self, val: c_int)
pub unsafe fn flags_raw(this: *const Self) -> c_int
pub unsafe fn set_flags_raw(this: *mut Self, val: c_int)
pub fn size(&self) -> c_int
pub fn set_size(&mut self, val: c_int)
pub unsafe fn size_raw(this: *const Self) -> c_int
pub unsafe fn set_size_raw(this: *mut Self, val: c_int)
pub fn new_bitfield_1( flags: c_int, size: c_int, ) -> __BindgenBitfieldUnit<[u8; 4]>
trait 实现
源代码impl Clone for AVIndexEntry
impl Clone for AVIndexEntry
源代码fn clone(&self) -> AVIndexEntry
fn clone(&self) -> AVIndexEntry
Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
从
source 执行拷贝赋值。 阅读更多源代码impl Debug for AVIndexEntry
impl Debug for AVIndexEntry
源代码impl PartialEq for AVIndexEntry
impl PartialEq for AVIndexEntry
impl Copy for AVIndexEntry
impl Eq for AVIndexEntry
impl StructuralPartialEq for AVIndexEntry
自动 trait 实现
impl Freeze for AVIndexEntry
impl RefUnwindSafe for AVIndexEntry
impl Send for AVIndexEntry
impl Sync for AVIndexEntry
impl Unpin for AVIndexEntry
impl UnsafeUnpin for AVIndexEntry
impl UnwindSafe for AVIndexEntry
blanket 实现
源代码impl<T> BorrowMut<T> for Twhere
T: ?Sized,
impl<T> BorrowMut<T> for Twhere
T: ?Sized,
源代码fn borrow_mut(&mut self) -> &mut T
fn borrow_mut(&mut self) -> &mut T
从拥有的值可变地借用。 阅读更多