#[repr(C)]pub struct AVOptionArrayDef {
pub def: *const c_char,
pub size_min: c_uint,
pub size_max: c_uint,
pub sep: c_char,
}展开描述
May be set as default_val for AV_OPT_TYPE_FLAG_ARRAY options.
Fields
def: *const c_charNative access only.
Default value of the option, as would be serialized by av_opt_get() (i.e. using the value of sep as the separator).
size_min: c_uintMinimum number of elements in the array. When this field is non-zero, def must be non-NULL and contain at least this number of elements.
size_max: c_uintMaximum number of elements in the array, 0 when unlimited.
sep: c_charSeparator between array elements in string representations of this option, used by av_opt_set() and av_opt_get(). It must be a printable ASCII character, excluding alphanumeric and the backslash. A comma is used when sep=0.
The separator and the backslash must be backslash-escaped in order to appear in string representations of the option value.
trait 实现
源代码impl Clone for AVOptionArrayDef
impl Clone for AVOptionArrayDef
源代码fn clone(&self) -> AVOptionArrayDef
fn clone(&self) -> AVOptionArrayDef
Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
从
source 执行拷贝赋值。 阅读更多源代码impl Debug for AVOptionArrayDef
impl Debug for AVOptionArrayDef
源代码impl PartialEq for AVOptionArrayDef
impl PartialEq for AVOptionArrayDef
impl Copy for AVOptionArrayDef
impl Eq for AVOptionArrayDef
impl StructuralPartialEq for AVOptionArrayDef
自动 trait 实现
impl Freeze for AVOptionArrayDef
impl RefUnwindSafe for AVOptionArrayDef
impl !Send for AVOptionArrayDef
impl !Sync for AVOptionArrayDef
impl Unpin for AVOptionArrayDef
impl UnsafeUnpin for AVOptionArrayDef
impl UnwindSafe for AVOptionArrayDef
blanket 实现
源代码impl<T> BorrowMut<T> for Twhere
T: ?Sized,
impl<T> BorrowMut<T> for Twhere
T: ?Sized,
源代码fn borrow_mut(&mut self) -> &mut T
fn borrow_mut(&mut self) -> &mut T
从拥有的值可变地借用。 阅读更多