跳到主要内容

AVPacketSideData

搜索

结构体 AVPacketSideData 

源代码
#[repr(C)]
pub struct AVPacketSideData { pub data: *mut u8, pub size: usize, pub type_: AVPacketSideDataType, }
展开描述

This structure stores auxiliary information for decoding, presenting, or otherwise processing the coded stream. It is typically exported by demuxers and encoders and can be fed to decoders and muxers either in a per packet basis, or as global side data (applying to the entire coded stream).

Global side data is handled as follows:

  • During demuxing, it may be exported through @ref AVCodecParameters.coded_side_data “AVStream’s codec parameters”, which can then be passed as input to decoders through the @ref AVCodecContext.coded_side_data “decoder context’s side data”, for initialization.
  • For muxing, it can be fed through @ref AVCodecParameters.coded_side_data “AVStream’s codec parameters”, typically the output of encoders through the @ref AVCodecContext.coded_side_data “encoder context’s side data”, for initialization.

Packet specific side data is handled as follows:

  • During demuxing, it may be exported through @ref AVPacket.side_data “AVPacket’s side data”, which can then be passed as input to decoders.
  • For muxing, it can be fed through @ref AVPacket.side_data “AVPacket’s side data”, typically the output of encoders.

Different modules may accept or export different types of side data depending on media type and codec. Refer to @ref AVPacketSideDataType for a list of defined types and where they may be found or used.

Fields

data: *mut u8size: usizetype_: AVPacketSideDataType

trait 实现

源代码

impl Clone for AVPacketSideData

源代码

fn clone(&self) -> AVPacketSideData

Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码

fn clone_from(&mut self, source: &Self)

source 执行拷贝赋值。 阅读更多
源代码

impl Debug for AVPacketSideData

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化该值。 阅读更多
源代码

impl PartialEq for AVPacketSideData

源代码

fn eq(&self, other: &AVPacketSideData) -> bool

Tests for self and other values to be equal, and is used by ==.
1.0.0 · 源代码

fn ne(&self, other: &Rhs) -> bool

测试 !=。默认实现几乎总是足够的,没有充分理由不应被重写。
源代码

impl Copy for AVPacketSideData

源代码

impl Eq for AVPacketSideData

源代码

impl StructuralPartialEq for AVPacketSideData

自动 trait 实现

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

获取 selfTypeId阅读更多
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

从拥有的值不可变地借用。 阅读更多
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

从拥有的值可变地借用。 阅读更多
源代码

impl<T> CloneToUninit for T
where T: Clone,

源代码

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
self 执行拷贝赋值到 dest阅读更多
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of From<T> for U 实现选择执行的操作。

源代码

impl<T> ToOwned for T
where T: Clone,

源代码

type Owned = T

获取所有权后得到的类型。
源代码

fn to_owned(&self) -> T

通常通过克隆,从借用数据创建拥有的数据。 阅读更多
源代码

fn clone_into(&self, target: &mut T)

通常通过克隆,使用借用数据替换拥有的数据。 阅读更多
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行该转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行该转换。