跳到主要内容

AVSubtitleRect

搜索

结构体 AVSubtitleRect 

源代码
#[repr(C)]
pub struct AVSubtitleRect { pub x: c_int, pub y: c_int, pub w: c_int, pub h: c_int, pub nb_colors: c_int, pub data: [*mut u8; 4], pub linesize: [c_int; 4], pub flags: c_int, pub type_: AVSubtitleType, pub text: *mut c_char, pub ass: *mut c_char, }

Fields

x: c_int

< top left corner of pict, undefined when pict is not set

y: c_int

< top left corner of pict, undefined when pict is not set

w: c_int

< width of pict, undefined when pict is not set

h: c_int

< height of pict, undefined when pict is not set

nb_colors: c_int

< number of colors in pict, undefined when pict is not set

data: [*mut u8; 4]

data+linesize for the bitmap of this subtitle. Can be set for text/ass as well once they are rendered.

linesize: [c_int; 4]flags: c_inttype_: AVSubtitleTypetext: *mut c_char

< 0 terminated plain UTF-8 text

ass: *mut c_char

0 terminated ASS/SSA compatible event line. The presentation of this is unaffected by the other values in this struct.

trait 实现

源代码

impl Clone for AVSubtitleRect

源代码

fn clone(&self) -> AVSubtitleRect

Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码

fn clone_from(&mut self, source: &Self)

source 执行拷贝赋值。 阅读更多
源代码

impl Debug for AVSubtitleRect

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化该值。 阅读更多
源代码

impl PartialEq for AVSubtitleRect

源代码

fn eq(&self, other: &AVSubtitleRect) -> bool

Tests for self and other values to be equal, and is used by ==.
1.0.0 · 源代码

fn ne(&self, other: &Rhs) -> bool

测试 !=。默认实现几乎总是足够的,没有充分理由不应被重写。
源代码

impl Copy for AVSubtitleRect

源代码

impl Eq for AVSubtitleRect

源代码

impl StructuralPartialEq for AVSubtitleRect

自动 trait 实现

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

获取 selfTypeId阅读更多
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

从拥有的值不可变地借用。 阅读更多
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

从拥有的值可变地借用。 阅读更多
源代码

impl<T> CloneToUninit for T
where T: Clone,

源代码

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
self 执行拷贝赋值到 dest阅读更多
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of From<T> for U 实现选择执行的操作。

源代码

impl<T> ToOwned for T
where T: Clone,

源代码

type Owned = T

获取所有权后得到的类型。
源代码

fn to_owned(&self) -> T

通常通过克隆,从借用数据创建拥有的数据。 阅读更多
源代码

fn clone_into(&self, target: &mut T)

通常通过克隆,使用借用数据替换拥有的数据。 阅读更多
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行该转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行该转换。