跳到主要内容

__BindgenBitfieldUnit

搜索

结构体 __BindgenBitfieldUnit 

源代码
pub struct __BindgenBitfieldUnit<Storage> { /* 私有字段 */ }

实现

源代码

impl<Storage> __BindgenBitfieldUnit<Storage>

源代码

pub const fn new(storage: Storage) -> Self

源代码

impl<Storage> __BindgenBitfieldUnit<Storage>
where Storage: AsRef<[u8]> + AsMut<[u8]>,

源代码

pub fn get_bit(&self, index: usize) -> bool

源代码

pub unsafe fn raw_get_bit(this: *const Self, index: usize) -> bool

源代码

pub fn set_bit(&mut self, index: usize, val: bool)

源代码

pub unsafe fn raw_set_bit(this: *mut Self, index: usize, val: bool)

源代码

pub fn get(&self, bit_offset: usize, bit_width: u8) -> u64

源代码

pub unsafe fn raw_get( this: *const Self, bit_offset: usize, bit_width: u8, ) -> u64

源代码

pub fn set(&mut self, bit_offset: usize, bit_width: u8, val: u64)

源代码

pub unsafe fn raw_set( this: *mut Self, bit_offset: usize, bit_width: u8, val: u64, )

trait 实现

源代码

impl<Storage: Clone> Clone for __BindgenBitfieldUnit<Storage>

源代码

fn clone(&self) -> __BindgenBitfieldUnit<Storage>

Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码

fn clone_from(&mut self, source: &Self)

source 执行拷贝赋值。 阅读更多
源代码

impl<Storage: Debug> Debug for __BindgenBitfieldUnit<Storage>

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化该值。 阅读更多
源代码

impl<Storage: Default> Default for __BindgenBitfieldUnit<Storage>

源代码

fn default() -> __BindgenBitfieldUnit<Storage>

返回类型的"默认值"。 阅读更多
源代码

impl<Storage: Hash> Hash for __BindgenBitfieldUnit<Storage>

源代码

fn hash<__H: Hasher>(&self, state: &mut __H)

Feeds this value into the given Hasher. 阅读更多
1.3.0 · 源代码

fn hash_slice<H>(data: &[Self], state: &mut H)
where H: Hasher, Self: Sized,

Feeds a slice of this type into the given Hasher. 阅读更多
源代码

impl<Storage: Ord> Ord for __BindgenBitfieldUnit<Storage>

源代码

fn cmp(&self, other: &__BindgenBitfieldUnit<Storage>) -> Ordering

This method returns an Ordering between self and other. 阅读更多
1.21.0 · 源代码

fn max(self, other: Self) -> Self
where Self: Sized,

Compares and returns the maximum of two values. 阅读更多
1.21.0 · 源代码

fn min(self, other: Self) -> Self
where Self: Sized,

Compares and returns the minimum of two values. 阅读更多
1.50.0 · 源代码

fn clamp(self, min: Self, max: Self) -> Self
where Self: Sized,

Restrict a value to a certain interval. 阅读更多
源代码

impl<Storage: PartialEq> PartialEq for __BindgenBitfieldUnit<Storage>

源代码

fn eq(&self, other: &__BindgenBitfieldUnit<Storage>) -> bool

Tests for self and other values to be equal, and is used by ==.
1.0.0 · 源代码

fn ne(&self, other: &Rhs) -> bool

测试 !=。默认实现几乎总是足够的,没有充分理由不应被重写。
源代码

impl<Storage: PartialOrd> PartialOrd for __BindgenBitfieldUnit<Storage>

源代码

fn partial_cmp( &self, other: &__BindgenBitfieldUnit<Storage>, ) -> Option<Ordering>

如果存在的话,该方法返回 selfother 之间的顺序。 阅读更多
1.0.0 · 源代码

fn lt(&self, other: &Rhs) -> bool

Tests less than (for self and other) and is used by the < operator. 阅读更多
1.0.0 · 源代码

fn le(&self, other: &Rhs) -> bool

Tests less than or equal to (for self and other) and is used by the <= operator. 阅读更多
1.0.0 · 源代码

fn gt(&self, other: &Rhs) -> bool

Tests greater than (for self and other) and is used by the > operator. 阅读更多
1.0.0 · 源代码

fn ge(&self, other: &Rhs) -> bool

Tests greater than or equal to (for self and other) and is used by the >= operator. 阅读更多
源代码

impl<Storage: Copy> Copy for __BindgenBitfieldUnit<Storage>

源代码

impl<Storage: Eq> Eq for __BindgenBitfieldUnit<Storage>

源代码

impl<Storage> StructuralPartialEq for __BindgenBitfieldUnit<Storage>

自动 trait 实现



impl<Storage> Freeze for __BindgenBitfieldUnit<Storage>
where Storage: Freeze,



impl<Storage> RefUnwindSafe for __BindgenBitfieldUnit<Storage>
where Storage: RefUnwindSafe,



impl<Storage> Send for __BindgenBitfieldUnit<Storage>
where Storage: Send,



impl<Storage> Sync for __BindgenBitfieldUnit<Storage>
where Storage: Sync,



impl<Storage> Unpin for __BindgenBitfieldUnit<Storage>
where Storage: Unpin,



impl<Storage> UnsafeUnpin for __BindgenBitfieldUnit<Storage>
where Storage: UnsafeUnpin,



impl<Storage> UnwindSafe for __BindgenBitfieldUnit<Storage>
where Storage: UnwindSafe,

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

获取 selfTypeId阅读更多
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

从拥有的值不可变地借用。 阅读更多
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

从拥有的值可变地借用。 阅读更多
源代码

impl<T> CloneToUninit for T
where T: Clone,

源代码

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
self 执行拷贝赋值到 dest阅读更多
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of From<T> for U 实现选择执行的操作。

源代码

impl<T> ToOwned for T
where T: Clone,

源代码

type Owned = T

获取所有权后得到的类型。
源代码

fn to_owned(&self) -> T

通常通过克隆,从借用数据创建拥有的数据。 阅读更多
源代码

fn clone_into(&self, target: &mut T)

通常通过克隆,使用借用数据替换拥有的数据。 阅读更多
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行该转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行该转换。